==> bordeaux_0.4.6.orig.tar.gz: bordeaux-0.4.6/cmake/features.cmake <==
# Test for compiler and runtime library features.
# Copyright (C) 2020-2021 David Sugar <tychosoft@gmail.com>.
#
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

include(CheckCXXSourceCompiles)
include(CheckIncludeFileCXX)
include(CheckFunctionExists)
include(FindPkgConfig)

find_package(OpenSSL REQUIRED)
include_directories(${OPENSSL_INCLUDE_DIR})
link_directories(${OPENSSL_LIBRARY_DIRS})

set(CMAKE_THREAD_PREFER_PTHREAD TRUE)
set(THREADS_PREFER_PTHREAD_FLAG TRUE)
find_package(Threads REQUIRED)

CHECK_INCLUDE_FILE_CXX("format" HAVE_FORMAT)
if(NOT HAVE_FORMAT)
    pkg_check_modules(FMT fmt>=6.1.2 REQUIRED)
    include_directories(${FMT_INCLUDE_DIRS})
    link_directories(${FMT_LIBRARY_DIRS})
endif()

if(NOT EXISTS "${CMAKE_CURRENT_SOURCE_DIR}/vendor/")
    pkg_check_modules(MODERNCLI moderncli>=0.0.2 REQUIRED)
    include_directories(${MODERNCLI_INCLUDE_DIRS})
endif()

set(EXOSIP_LIBS eXosip2 osip2 osipparser2)
if(NOT EXISTS "${CMAKE_CURRENT_SOURCE_DIR}/vendor/" OR NOT BUILD_VENDOR)
    pkg_check_modules(OSIP2 libosip2>=5.3.0 QUIET)
endif()

if(OSIP2_FOUND)
    include_directories(${OSIP2_INCLUDE_DIRS})
    link_directories(${OSIP2_LIBRARY_DIRS})
elseif(EXISTS "${CMAKE_CURRENT_SOURCE_DIR}/vendor/")
    include_directories(BEFORE "${CMAKE_CURRENT_SOURCE_DIR}/vendor/libosip2/include" "${CMAKE_CURRENT_SOURCE_DIR}/vendor/libeXosip2/include")
    pkg_check_modules(CARES libcares>=1.13.0 REQUIRED)
    include_directories(${CARES_INCLUDE_DIRS})
    link_directories(${CARES_LIBRARY_DIRS})
    list(APPEND EXOSIP_LIBS ${CARES_LIBRARIES} OpenSSL::Crypto)
else()
    message(FATAL_ERROR "libosip2 and/or libeXosip2 not found")
endif()

# Optional module features...
pkg_check_modules(MQTT libmosquitto>=1.4 QUIET)
if(MQTT_FOUND)
    include_directories(${MQTT_INCLUDE_DIRS})
    link_directories(${MQTT_LIBRARY_DIRS})
endif()

if(CMAKE_BUILD_TYPE MATCHES "Debug")
    set(BUILD_DEBUG true)
    add_definitions(-DDEBUG)
else()
    add_definitions(-DNDEBUG)
    pkg_search_module(MALLOC jemalloc IMPORTED_TARGET)
endif()

==> bordeaux_0.7.8.orig.tar.gz: bordeaux-0.7.8/cmake/features.cmake <==
# Test for compiler and runtime library features.
# Copyright (C) 2020-2021 David Sugar <tychosoft@gmail.com>.
#
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

include(CheckCXXSourceCompiles)
include(CheckIncludeFileCXX)
include(CheckFunctionExists)
include(FindPkgConfig)

find_package(OpenSSL REQUIRED)
include_directories(${OPENSSL_INCLUDE_DIR})
link_directories(${OPENSSL_LIBRARY_DIRS})

set(CMAKE_THREAD_PREFER_PTHREAD TRUE)
set(THREADS_PREFER_PTHREAD_FLAG TRUE)
find_package(Threads REQUIRED)

check_include_file_cxx(flite/flite.h FLITE_FOUND)
if(FLITE_FOUND)
    add_definitions("-DFLITE")
    set(FLITE_LIBRARIES flite_cmu_us_slt flite_usenglish flite_cmulex flite)
endif()

pkg_check_modules(SYSTEMD libsystemd QUIET)
if(SYSTEMD_FOUND)
    include_directories(${SYSTEMD_INCLUDE_DIRS})
    link_directories(${SYSTEMD_LIBRARY_DIRS})
    add_definitions("-DSYSTEMD_SERVICE")
endif()

pkg_check_modules(FMT fmt>=6.1.2 REQUIRED)
pkg_check_modules(JSON RapidJSON>=1.1.0 REQUIRED)

include_directories(${FMT_INCLUDE_DIRS} ${JSON_INCLUDE_DIRS})
link_directories(${FMT_LIBRARY_DIRS})

set(EXOSIP_LIBS eXosip2 osip2 osipparser2)
if(NOT EXISTS "${CMAKE_CURRENT_SOURCE_DIR}/vendor/" OR NOT BUILD_VENDOR)
    pkg_check_modules(OSIP2 libosip2>=5.3.0 QUIET)
endif()

if(OSIP2_FOUND)
    include_directories(${OSIP2_INCLUDE_DIRS})
    link_directories(${OSIP2_LIBRARY_DIRS})
elseif(EXISTS "${CMAKE_CURRENT_SOURCE_DIR}/vendor/")
    include_directories(BEFORE "${CMAKE_CURRENT_SOURCE_DIR}/vendor/libosip2/include" "${CMAKE_CURRENT_SOURCE_DIR}/vendor/libeXosip2/include")
    pkg_check_modules(CARES libcares>=1.13.0 REQUIRED)
    include_directories(${CARES_INCLUDE_DIRS})
    link_directories(${CARES_LIBRARY_DIRS})
    list(APPEND EXOSIP_LIBS ${CARES_LIBRARIES} OpenSSL::Crypto)
else()
    message(FATAL_ERROR "libosip2 and/or libeXosip2 not found")
endif()

if(CMAKE_BUILD_TYPE MATCHES "Debug")
    set(BUILD_DEBUG true)
    add_definitions(-DDEBUG)
else()
    add_definitions(-DNDEBUG)
    pkg_search_module(MALLOC jemalloc IMPORTED_TARGET)
endif()

check_include_file_cxx(mqueue.h FOUND_MQUEUE)
if(NOT FOUND_MQUEUE)
    message(FATAL_ERROR "posix mqueue support required")
endif()
set(RT_LIBRARIES rt)
